## Python-ecosystem packages

These MicroPython versions of common Python packages, typically found on PyPI.

If a package has the same name as a PyPI package, then it should match at
least some subset of the functionality.

### Future plans

* More organised directory structure based on library purpose (e.g. drivers, network, etc).
